##  Linking Diagram to Other Diagrams
This feature enables you to manage large and complex architectural diagrams effectively. You can create multiple diagrams with varying levels of detail and link them to navigate across different abstraction layers.
In the diagram editor, you can link a diagram directly to a shape through a hyperlink. Clicking the shape opens the linked diagram in a new browser tab.
However, the following conditions should be kept in mind:
  * You can not link a diagram to a shape if the shape is already linked to a fact sheet.
  * You can not link a diagram to a shape that is a 'connector.'
  * A shape can be linked to only one diagram.


To link a diagram to a shape, do the following:
  1. Right-click on the shape you want to connect the diagram to
  2. Select Link to diagram from the menu
  3. The diagram quick search will appear, which shows you a list of all existing diagrams in your workspace. Scroll to choose one or start typing to find the diagram you need.


To unlink a diagram that is linked to a shape, do the following:
  1. Right-click on the shape to which the diagram is connected
  2. Select Unlink diagram


Similarly, you can change or open the linked diagram by selecting Change diagram or Open diagram from the right-click menu.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2752cc037a441014a195aecbf5272692_LowRes.png)
**Note**
Linking diagrams to fact sheets enables you to access relevant diagrams directly from the fact sheet. You can link the diagram in the Resources tab of the fact sheet. For detailed instruction, see [Storing Resources on Fact Sheets](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio27592c207a441014b142ca56bfa9decf__storing_resources_on_fact_sheets). Linked diagrams are then visible both in the Resources tab, as well as on the fact sheet sidebar.
